﻿using UnityEngine;
using System.Collections;

public class playerWeapons : MonoBehaviour {

	//bullet objects found in the Prefabs folder
	public GameObject[] bullets;
	//damage for each bullet
	public float[] bulletsDamage;
	//speed for each bullet
	public float[] bulletsSpeed;
	//firerate for each bullet
	public float[] bulletsFirerate;
	//spawn position of bullet
	public Transform spawnPosition;
	//sound of the bullet when fired
	public AudioClip bulletSound;
	//sound when you pick up a bullet upgrade. by default we just used the same sound as the heart pickup.
	public AudioClip pickupSound;
	
	//private variables used to control shooting bullets
	private float bulletCounter = 0.0f;
	private float bulletPos = 0.0f;
	private int weaponSet = 0;
	private GameObject currentBullet;
	private float currentSpeed;
	private float currentDamage;
	private float fireRate = 0.25f;
	private bool dead = false;
	
	void Start () {
		//when the game starts we want to check to see what bullet the player was using last. This is also called when a pickup is hit.
		updateBulletType();
	}
	
	void Update () {
		//keep track of time so we know when a bullet can fire
		bulletCounter += Time.deltaTime;
		
		if(!dead){
			//controls for shooting bullets for web versions of the game. These are the same as standalone, but are only compiled if its web
			#if UNITY_STANDALONE || UNITY_WEBPLAYER
			if(Input.GetKey(KeyCode.LeftShift)){
				if(bulletCounter > fireRate){
					shootBullet();
				}
			}
			#endif
			
			//controls for shooting bullets for ios versions of the game. These are the same as android, but are only compiled if its ios
			#if UNITY_IOS || UNITY_ANDROID
			if(Input.touchCount > 0){
				for(var touch1 : Touch in Input.touches) { 
					//2nd touch for jump button
					if(touch1.position.x > Screen.width/2 && touch1.position.x < Screen.width/4*3 && touch1.position.y < Screen.height/3){
						if(bulletCounter > fireRate){
							shootBullet();
						}	
					}
				}
			}
			#endif
		}
		
		//end of function update
	}
	
	void shootBullet () {
		Vector3 pos = new Vector3(bulletPos+transform.position.x,-0.25f+transform.position.y,0.01f+transform.position.z);
		GameObject bulletPrefab = Instantiate(currentBullet, pos, Quaternion.Euler(0,180,0)) as GameObject;
		bulletPrefab.SendMessage("getDamageAmount", currentDamage, SendMessageOptions.DontRequireReceiver);
		audio.PlayOneShot(bulletSound);
		if(spawnPosition.position.x > transform.position.x){
			bulletPrefab.transform.rigidbody.velocity = new Vector3(currentSpeed,0,0);
		}else{
			bulletPrefab.transform.rigidbody.velocity =  new Vector3(-currentSpeed,0,0);
		}
		bulletCounter = 0.0f;
	}
	
	void updateBulletType () {
		var getSet = PlayerPrefs.GetInt("weaponset");
		if(getSet >= bullets.Length){
			getSet = bullets.Length-1;
		}
		currentBullet = bullets[getSet];
		fireRate = bulletsFirerate[getSet];
		currentSpeed = bulletsSpeed[getSet];
		currentDamage = bulletsDamage[getSet];
	}
	
	//this will happen if a trigger collider hits it. we check the tag though so only objects tagged with pickup will make this happen. it upgrades the weapons on pickup.
	void OnTriggerEnter (Collider other){
		if(other.tag == "pickup"){
			Destroy(other.gameObject);
			audio.PlayOneShot(pickupSound);
			if(weaponSet < bullets.Length-1){
				weaponSet = PlayerPrefs.GetInt("weaponset") + 1;
				PlayerPrefs.SetInt("weaponset", weaponSet);
				updateBulletType();
			}
		}
	}
	
	void died () {
		dead = true;
	}
}
