#pragma strict

var walkSpeed:float = 14.0;
var jumpHeight:float = 8.0;
var fallLimit:float = -10;
var jumpSound:AudioClip;

private var hit:RaycastHit;
private var jumpCounter:float = 0.0;
private var controller:CharacterController;
private var vel:Vector3;
private var origX:float;
private var canControl = true;
private var canCeiling = true;

function Start () {
	controller = GetComponent(CharacterController);
	origX = transform.localScale.x;
}

function Update () {

	//Apply Gravity
	if(!controller.isGrounded){
		vel.y -= Time.deltaTime*80;
		jumpCounter += Time.deltaTime;
	}else{
		vel.y = -1;
		jumpCounter = 0.0;
	}
	
	//Flip Player based on velocity
	if(controller.velocity.x > 0){
		transform.localScale.x = origX;
	}
	if(controller.velocity.x < 0){
		transform.localScale.x = -origX;
	}

	if(canControl){
		#if UNITY_STANDALONE || UNITY_WEBPLAYER
			if(Input.GetKey("a") || Input.GetKey("d") || Input.GetKey("left") || Input.GetKey("right")){
				if(Input.GetKey("a") || Input.GetKey(KeyCode.LeftArrow)){
					vel.x = -walkSpeed;
				}
				if(Input.GetKey("d") || Input.GetKey(KeyCode.RightArrow)){
					vel.x = walkSpeed;
				}
			}else{
				vel.x = 0;
			}
			if(Input.GetKey("w") || Input.GetKey(KeyCode.UpArrow)){
				if(jumpCounter < 0.125){
					vel.y = jumpHeight;
					jumpCounter = 0.125;
					audio.PlayOneShot(jumpSound);
				}
			}
		#endif

		#if UNITY_IOS || UNITY_ANDROID
			if(Input.touchCount > 0){
				for(var touch1 : Touch in Input.touches) {
					if(touch1.position.x < Screen.width/5 && touch1.position.y < Screen.height/3){
						vel.x = -walkSpeed;
					}
					if(touch1.position.x > Screen.width/5 && touch1.position.x < Screen.width/5*2 && touch1.position.y < Screen.height/3){
						vel.x = walkSpeed;
					}
					if(Input.touchCount == 1 && touch1.position.x > Screen.width/2){
						vel.x = 0;
					}
				}
			}else{
				vel.x = 0;
			}

			if(Input.touchCount > 0){
				for(var touch2 : Touch in Input.touches) { 
					if(touch2.position.x > Screen.width/4*3 && touch2.position.y < Screen.height/3){
						if(Input.touchCount == 1){
							vel.x = 0;
						}
						if(jumpCounter < 0.125){
							vel.y = jumpHeight;
							jumpCounter = 0.125;
							audio.PlayOneShot(jumpSound);
						}
					}
				}
			}
		#endif
	}
	
	if ((controller.collisionFlags & CollisionFlags.Above) != 0 && canCeiling){
		canCeiling = false;
		vel.y = 0;
		resetCeiling();
	}
	
	//Apply movement to player based on vel variable which is a Vector3.
	controller.Move(vel*Time.deltaTime);
	
	//reset level if player falls past Fall Limit
	if(transform.position.y < fallLimit){
		var lvlName:String = Application.loadedLevelName;
		Application.LoadLevel(lvlName);
	}
}

function resetCeiling () {
	yield WaitForSeconds(0.25);
	canCeiling = true;
}

function died () {
	canControl = false;
	vel.x = 0;
}