#pragma strict

//here are public variables that can be edited in the inspector for the players health.
var hearts:int = 6;
//sound when he's hit
var hitSound:AudioClip;
//death animation if he dies
var deathAnim:GameObject;
//the 3 different heart textures that will be changed in the hearts at the top of the screen depending on his health.
var heartWhole:Texture;
var heartHalf:Texture;
var heartEmpty:Texture;
//the sound if a heart is picked up
var heartSound:AudioClip;

private var dead = false;
private var canGetHurt = true;
private var rend:SpriteRenderer;
private var heartsGUI:GUITexture[];
private var health:int;

function Start () {
	health = hearts*2;
	var getHearts = GameObject.Find("GUI/hearts");
	getHearts.SendMessage("addHearts", hearts, SendMessageOptions.DontRequireReceiver);
	//yield WaitForSeconds(0.1);
	yield WaitForEndOfFrame;
	var allChildren = getHearts.GetComponentsInChildren(GUITexture);
	heartsGUI = new GUITexture[allChildren.Length];
	health = allChildren.Length*2;
	for(var i:int = 0;i < allChildren.Length;i++){
		heartsGUI[i] = allChildren[i] as GUITexture;
	}
	rend = GetComponent(SpriteRenderer);
}

function takeDamage (amount : int) {
	if(canGetHurt && !dead){
		canGetHurt = false;
		audio.PlayOneShot(hitSound);
		health -= amount;
		checkHealth();
		resetCanHurt();
	}
}

//here we check to see if the we hit an enemy or spikes, but we won't get hurt if our color was changed because that was the indication that we were hurt not too long ago. like 0.25 seconds ago.
function OnTriggerStay (other : Collider){
	if(other.tag == "enemy" || other.tag == "spikes"){
		if(canGetHurt && !dead){
			canGetHurt = false;
			audio.PlayOneShot(hitSound);
			health -= 1;
			checkHealth();
			resetCanHurt();
		}
	}
	//if its a heart though, we want health back instead of taken away.
	if(other.collider.tag == "heart"){
		Destroy(other.gameObject);
		addHealth();
	}
}

//this is the same as ontriggerstay, but for enemy's whose colliders aren't triggers.
function OnCollisionStay (other : Collision){
	if(other.collider.tag == "enemy" || other.collider.tag == "spikes"){
		if(canGetHurt && !dead){
			canGetHurt = false;
			audio.PlayOneShot(hitSound);
			health -= 1;
			checkHealth();
			resetCanHurt();
		}
	}
}

function resetCanHurt () {
	rend.color.b = 0.25;
	rend.color.g = 0.25;
	yield WaitForSeconds(0.25);
	rend.color.b = 1.0;
	rend.color.g = 1.0;
	canGetHurt = true;
}

//here we checkhealth when a player is hit by an enemy.
function checkHealth () {
	//here we update the hearts on the screen so that they show an accurate health amount
	updateHearts();
	// if health is 0 then we're going to do all of this stuff once, which is why we check to see if dead was previously false.
	//it turns off a bunch of stuff like physics, renderers, scripts, then waits for 3 seconds before it reloads the scene again.	
	if(health <= 0 && dead == false){
		dead = true;
		Instantiate(deathAnim, transform.position, Quaternion.Euler(0,180,0));
		BroadcastMessage("died", SendMessageOptions.DontRequireReceiver);
		var rend = GetComponent(SpriteRenderer);
		rend.enabled = false;
		yield WaitForSeconds(3);
		var lvlName:String = Application.loadedLevelName;
		Application.LoadLevel(lvlName);
	}
}

//here we add health back.
function addHealth () {
	audio.PlayOneShot(heartSound);
	health += 2;
	//if the players health is more than 6, we want to make sure its 6 because thats the max we chose.
	if(health > 6){
		health = 6;
	}
	//here we update the hearts on the screen so that they show an accurate health amount
	updateHearts();
}

function updateHearts () {	
	//here we check how much health the player has, then apply the texture to the hearts in GUI/hearts accordingly
	for(var i:int = 0;i < heartsGUI.Length;i++){
		var check:int = (i+1)*2;
		if(check < health+1){
			heartsGUI[i].texture = heartWhole;
		}
		if(check == health+1){
			heartsGUI[i].texture = heartHalf;
		}
		if(check > health+1){
			heartsGUI[i].texture = heartEmpty;
		}
	}
}