#pragma strict

//bullet objects found in the Prefabs folder
var bullets:GameObject[];
//damage for each bullet
var bulletsDamage:float[];
//speed for each bullet
var bulletsSpeed:float[];
//firerate for each bullet
var bulletsFirerate:float[];
//spawn position of bullet
var spawnPosition:Transform;
//sound of the bullet when fired
var bulletSound:AudioClip;
//sound when you pick up a bullet upgrade. by default we just used the same sound as the heart pickup.
var pickupSound:AudioClip;

//private variables used to control shooting bullets
private var bulletCounter:float = 0.0;
private var bulletPos:float = 0.0;
private var weaponSet:float = 0.0;
private var currentBullet:GameObject;
private var currentSpeed:float;
private var currentDamage:float;
private var fireRate:float = 0.25;
private var dead = false;

function Start () {
	//when the game starts we want to check to see what bullet the player was using last. This is also called when a pickup is hit.
	updateBulletType();
}

function Update () {
	//keep track of time so we know when a bullet can fire
	bulletCounter += Time.deltaTime;
	
	if(!dead){
		//controls for shooting bullets for web versions of the game. These are the same as standalone, but are only compiled if its web
		#if UNITY_STANDALONE || UNITY_WEBPLAYER
		if(Input.GetKey(KeyCode.LeftShift)){
			if(bulletCounter > fireRate){
				shootBullet();
			}
		}
		#endif

		//controls for shooting bullets for ios versions of the game. These are the same as android, but are only compiled if its ios
		#if UNITY_IOS || UNITY_ANDROID
		if(Input.touchCount > 0){
			for(var touch1 : Touch in Input.touches) { 
			//2nd touch for jump button
				if(touch1.position.x > Screen.width/2 && touch1.position.x < Screen.width/4*3 && touch1.position.y < Screen.height/3){
					if(bulletCounter > fireRate){
						shootBullet();
					}	
				}
			}
		}
		#endif
	}

//end of function update
}

function shootBullet () {
	var bulletPrefab = Instantiate(currentBullet, transform.position + Vector3(bulletPos,-0.25,0.01), Quaternion.Euler(0,180,0));
	bulletPrefab.SendMessage("getDamageAmount", currentDamage, SendMessageOptions.DontRequireReceiver);
	audio.PlayOneShot(bulletSound);
	if(spawnPosition.position.x > transform.position.x){
		bulletPrefab.transform.rigidbody.velocity.x = currentSpeed;
	}else{
		bulletPrefab.transform.rigidbody.velocity.x = -currentSpeed;
	}
	bulletCounter = 0.0;
}

function updateBulletType () {
	var getSet = PlayerPrefs.GetInt("weaponset");
	if(getSet >= bullets.Length){
		getSet = bullets.Length-1;
	}
	currentBullet = bullets[getSet];
	fireRate = bulletsFirerate[getSet];
	currentSpeed = bulletsSpeed[getSet];
	currentDamage = bulletsDamage[getSet];
}

//this will happen if a trigger collider hits it. we check the tag though so only objects tagged with pickup will make this happen. it upgrades the weapons on pickup.
function OnTriggerEnter (other : Collider){
	if(other.tag == "pickup"){
		Destroy(other.gameObject);
		audio.PlayOneShot(pickupSound);
		if(weaponSet < bullets.Length-1){
			weaponSet = PlayerPrefs.GetInt("weaponset") + 1;
			PlayerPrefs.SetInt("weaponset", weaponSet);
			updateBulletType();
		}
	}
}

function died () {
	dead = true;
}