#pragma strict

//here are the public variables for the shooter enemy. these can be changed in the inspector.
var runSpeed:float = 4.0;
//the sound when he shoots a bullet
var shootSound:AudioClip;
//the textures that make him look like an enemy
var run:Sprite[];
var shoot:Sprite[];
//the bullet he shoots
var enemyBullet:GameObject;
var bulletSpeed:float = 16.0;
var bulletPosition:Transform;

//private variables that help with animating the enemy
private var controller:CharacterController;
private var counter:float = 0.0;
private var i:int = 0;
private var target:GameObject;
private var distance:float = 0.0;
private var ydistance:float = 0.0;
private var frameRate:float = 8.0;
private var shooting = false;
private var rend:SpriteRenderer;
private var origX:float;
private var vel:Vector3;

//we want to use the player as a reference for animating and giving a simple AI.
function Start () {
	controller = GetComponent(CharacterController);
	rend = GetComponent(SpriteRenderer);
	target = GameObject.Find("Player");
	Physics.IgnoreCollision(target.collider, collider);
	origX = transform.localScale.x;
	//here it makes it ignore other enemy colliders so they can't get caught on each other.
	var enemies = GameObject.FindGameObjectsWithTag("enemy");
	for (var en : GameObject in enemies)  {
		if (en.collider != collider) {
			Physics.IgnoreCollision(collider, en.collider);
		}
	}
}

function Update () {
	//Apply Gravity
	if(!controller.isGrounded){
		vel.y -= Time.deltaTime*80;
	}else{
		vel.y = -1;
	}
	//here we check the distance away the player is from the enemy
	distance = target.transform.position.x - transform.position.x;
	ydistance = target.transform.position.y - transform.position.y;
	if(distance < 0){
		distance *= -1;
	}
	if(ydistance < 0){
		ydistance *= -1;
	}
	if(target.transform.position.x > transform.position.x){
		transform.localScale.x = origX;
	}
	if(target.transform.position.x < transform.position.x){
		transform.localScale.x = -origX;
	}

	//if the player is close enough. the enemy can start animating and doing its thing.
	if(distance < 16 && ydistance < 8){
		counter += Time.deltaTime*frameRate;
		if(distance > 9 && distance < 16 && !shooting){
			if(target.transform.position.x < transform.position.x){
				vel.x = -runSpeed;
			}
			if(target.transform.position.x > transform.position.x){
				vel.x = runSpeed;
			}
			if(counter > i && i < run.Length){
				rend.sprite = run[i];
				i += 1;
			}
			if(counter > run.Length){
				counter = 0.0;
				i = 0;
			}
		}
		if(shooting){
			vel.x = 0;
			if(counter > i && i < shoot.Length){
				rend.sprite = shoot[i];
				i += 1;
			}
		}
		//the enemy will shoot a bullet only if the player is close enough and shooting is indeed false.
		if(distance < 9 && shooting == false){
			shootBullet();
		}
	}

	//if the enemy falls down a hole, we want to destroy it so it doesn't exist for no reason.
	if(transform.position.y < -10){
		Destroy(gameObject);
	}
	
	//Apply movement to player based on vel variable which is a Vector3.
	controller.Move(vel*Time.deltaTime);
}

//if the shooter wants to shoot a bullet, then this function is called.
function shootBullet () {
	vel.x = 0;
	shooting = true;
	counter = 0.0;
	i = 0;
	//we wait for a bit before the shot fires so that the player can see he's about to do it
	yield WaitForSeconds(0.5);
	//play the shot sound
	audio.PlayOneShot(shootSound);
	//spawn the bullet
	var bullet = Instantiate(enemyBullet, bulletPosition.position, Quaternion.Euler(0,0,0));
	//set velocity to the bullet
	if(bulletPosition.position.x < transform.position.x){
		bullet.rigidbody.velocity.x = -bulletSpeed;
	}else{
		bullet.rigidbody.velocity.x = bulletSpeed;
	}
	//then pause again before the enemy is ready to fire again.
	yield WaitForSeconds(0.5);
	shooting = false;
}